@@ -22,15 +22,14 @@
 #include "ui_dialogdesktop.h"
 #include <CalendarSupport/FreeBusyItemModel>
 
-#include <Akonadi/Contact/AbstractEmailAddressSelectionDialog>
-#include <Akonadi/Contact/ContactGroupExpandJob>
-#include <Akonadi/Contact/ContactGroupSearchJob>
-#include <Akonadi/Contact/EmailAddressSelectionDialog>
+#include <Akonadi/AbstractEmailAddressSelectionDialog>
+#include <Akonadi/ContactGroupExpandJob>
+#include <Akonadi/ContactGroupSearchJob>
+#include <Akonadi/EmailAddressSelectionDialog>
 
 #include <KCalUtils/Stringify>
 #include <KEmailAddress>
 #include <KPluginFactory>
-#include <KPluginLoader>
 
 #include "incidenceeditor_debug.h"
 #include <KLocalizedString>
@@ -107,7 +106,7 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
     connect(mUi->mOrganizerCombo, qOverload<const QString &>(&QComboBox::activated),
             this, &IncidenceAttendee::slotOrganizerChanged);
     */
-    connect(mUi->mOrganizerCombo, qOverload<int>(&QComboBox::currentIndexChanged), this, &IncidenceAttendee::checkDirtyStatus);
+    connect(mUi->mOrganizerCombo, &QComboBox::currentIndexChanged, this, &IncidenceAttendee::checkDirtyStatus);
 
     connect(mDateTime, &IncidenceDateTime::startDateChanged, this, &IncidenceAttendee::slotEventDurationChanged);
     connect(mDateTime, &IncidenceDateTime::endDateChanged, this, &IncidenceAttendee::slotEventDurationChanged);
@@ -142,9 +141,7 @@ IncidenceAttendee::IncidenceAttendee(QWidget *parent, IncidenceDateTime *dateTim
     connect(filterProxyModel, &AttendeeFilterProxyModel::layoutChanged, this, &IncidenceAttendee::filterLayoutChanged);
 }
 
-IncidenceAttendee::~IncidenceAttendee()
-{
-}
+IncidenceAttendee::~IncidenceAttendee() = default;
 
 void IncidenceAttendee::load(const KCalendarCore::Incidence::Ptr &incidence)
 {
@@ -207,7 +204,9 @@ void IncidenceAttendee::save(const KCalendarCore::Incidence::Ptr &incidence)
                                                 "%1 does not look like a valid email address. "
                                                 "Are you sure you want to invite this participant?",
                                                 attendee.email()),
-                                          i18nc("@title:window", "Invalid Email Address"))
+                                          i18nc("@title:window", "Invalid Email Address"),
+                                          KGuiItem(i18nc("@action:button", "Invite"), QStringLiteral("dialog-ok")),
+                                          KGuiItem(i18nc("@action:button", "Do Not Invite"), QStringLiteral("dialog-cancel")))
                 != KMessageBox::Yes) {
                 skip = true;
             }
@@ -419,10 +418,12 @@ void IncidenceAttendee::insertAddresses(const KContacts::Addressee::List &list)
 void IncidenceAttendee::slotSelectAddresses()
 {
     QPointer<Akonadi::AbstractEmailAddressSelectionDialog> dialog;
-    KPluginLoader loader(QStringLiteral("akonadi/emailaddressselectionldapdialogplugin"));
-    KPluginFactory *factory = loader.factory();
-    if (factory) {
-        dialog = factory->create<Akonadi::AbstractEmailAddressSelectionDialog>(mParentWidget);
+    const KPluginMetaData editWidgetPlugin(QStringLiteral("akonadi/emailaddressselectionldapdialogplugin"));
+
+    const auto result = KPluginFactory::instantiatePlugin<Akonadi::AbstractEmailAddressSelectionDialog>(editWidgetPlugin, mParentWidget);
+    if (result) {
+        dialog = result.plugin;
+
     } else {
         dialog = new Akonadi::EmailAddressSelectionDialog(mParentWidget);
     }
@@ -447,7 +448,7 @@ void IncidenceAttendee::slotSelectAddresses()
             } else {
                 KContacts::Addressee contact;
                 contact.setName(selection.name());
-                contact.insertEmail(selection.email());
+                contact.addEmail(KContacts::Email(selection.email()));
 
                 if (selection.item().hasPayload<KContacts::Addressee>()) {
                     contact.setUid(selection.item().payload<KContacts::Addressee>().uid());
@@ -776,7 +777,10 @@ void IncidenceAttendee::slotOrganizerChanged(const QString &newOrganizer)
                                             i18nc("@option",
                                                   "You are changing the organizer of this event. "
                                                   "Since the organizer is also attending this event, would you "
-                                                  "like to change the corresponding attendee as well?"));
+                                                  "like to change the corresponding attendee as well?"),
+                                            QString(),
+                                            KGuiItem(i18nc("@action:button", "Change Attendee"), QStringLiteral("dialog-ok")),
+                                            KGuiItem(i18nc("@action:button", "Do Not Change"), QStringLiteral("dialog-cancel")));
     } else {
         answer = KMessageBox::Yes;
     }
